#
# spec file for package elemental
#
# Copyright (c) 2022 - 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define commit 2dfcbfd19277089ca3aff8ca30d42844f4630aac
%define c_date 20241007

%define systemdir /system
%define oemdir %{systemdir}/oem

Name:           elemental
VCS: https://src.suse.de/SLFO-pool/elemental#651860dc68501c421832844545a1d94a181657949e54412f7d09a83f2270dd7c
Version:        2.2.0
Release:        160000.1.3
Summary:        A Rancher and Kubernetes optimized immutable Linux distribution
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/rancher/%{name}
Source:         %{name}.tar.xz
Source3:        %{name}-rpmlintrc

Requires:       elemental-toolkit >= 2.2.0
Requires:       elemental-toolkit < 2.3.0
Requires:       elemental-register
Requires:       elemental-system-agent
Requires:       elemental-support
Requires:       elemental-updater = %{version}-%{release}
Requires:       NetworkManager
Requires:       systemd-presets-branding-Elemental
Requires:       procps
%{?systemd_requires}

BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Elemental is a new set of tools to manage operating systems as container images within Rancher Manager

%package -n elemental-updater
Summary:        Rancher elemental node updater
Group:          System/Management

%description -n elemental-updater
Rancher elemental node updater. To be installed on the node.

%prep
%setup -q -n %{name}

%build


%install

cp -a framework/files/* %{buildroot}

rm -rf %{buildroot}/var/log/journal

%pre
%if 0%{?suse_version}
%service_add_pre elemental-populate-node-labels.service
%service_add_pre shutdown-containerd.service
%service_add_pre elemental-register.service
%service_add_pre elemental-register-install.service
%service_add_pre elemental-register-reset.service
%service_add_pre elemental-register.timer
%service_add_pre elemental-system-agent.service
%endif

%post
%if 0%{?suse_version}
%service_add_post elemental-populate-node-labels.service
%service_add_post shutdown-containerd.service
%service_add_post elemental-register.service
%service_add_post elemental-register-install.service
%service_add_post elemental-register-reset.service
%service_add_post elemental-register.timer
%service_add_post elemental-system-agent.service
%else
%systemd_post elemental-populate-node-labels.service
%systemd_post shutdown-containerd.service
%systemd_post elemental-register.service
%systemd_post elemental-register-install.service
%systemd_post elemental-register-reset.service
%systemd_post elemental-register.timer
%systemd_post elemental-system-agent.service
%endif

%preun
%if 0%{?suse_version}
%service_del_preun elemental-populate-node-labels.service
%service_del_preun shutdown-containerd.service
%service_del_preun elemental-register.service
%service_del_preun elemental-register-install.service
%service_del_preun elemental-register-reset.service
%service_del_preun elemental-register.timer
%service_del_preun elemental-system-agent.service
%else
%systemd_preun elemental-populate-node-labels.service
%systemd_preun shutdown-containerd.service
%systemd_preun elemental-register.service
%systemd_preun elemental-register-install.service
%systemd_preun elemental-register-reset.service
%systemd_preun elemental-register.timer
%systemd_preun elemental-system-agent.service
%endif

%postun
%if 0%{?suse_version}
%service_del_postun elemental-populate-node-labels.service
%service_del_postun shutdown-containerd.service
%service_del_postun elemental-register.service
%service_del_postun elemental-register-install.service
%service_del_postun elemental-register-reset.service
%service_del_postun elemental-register.timer
%service_del_postun elemental-system-agent.service
%else
%systemd_postun elemental-populate-node-labels.service
%systemd_postun shutdown-containerd.service
%systemd_postun elemental-register.service
%systemd_postun elemental-register-install.service
%systemd_postun elemental-register-reset.service
%systemd_postun elemental-register.timer
%systemd_postun elemental-system-agent.service
%endif

%files
%defattr(-,root,root,-)
%doc README.md
%license LICENSE
%dir %{_sysconfdir}/elemental
%config %{_sysconfdir}/elemental/bootargs.cfg
%dir %{_sysconfdir}/elemental/config.d
%config %{_sysconfdir}/elemental/config.d/*
%dir %{_sysconfdir}/dracut.conf.d
%config %{_sysconfdir}/dracut.conf.d/51-certificates-initrd.conf
%config %{_sysconfdir}/dracut.conf.d/99-elemental-systemd.conf
%dir %{_sysconfdir}/NetworkManager
%dir %{_sysconfdir}/NetworkManager/conf.d
%config %{_sysconfdir}/NetworkManager/conf.d/rke2-canal.conf
%dir %{_unitdir}
%{_unitdir}/shutdown-containerd.service
%{_unitdir}/elemental-register.service
%{_unitdir}/elemental-register-install.service
%{_unitdir}/elemental-register-reset.service
%{_unitdir}/elemental-register.timer
%{_unitdir}/elemental-populate-node-labels.service
%{_unitdir}/elemental-system-agent.service
%{_sbindir}/elemental-populate-node-labels
%dir %{_libexecdir}/elemental-checker
%{_libexecdir}/elemental-checker/elemental-register.sh
%dir %{systemdir}
%dir %{oemdir}
%{oemdir}/*

%files -n elemental-updater
%defattr(-,root,root,-)
%license LICENSE
%{_sbindir}/self-upgrade
%{_sbindir}/suc-upgrade

%changelog
* Mon Oct  7 2024 elemental@suse.de
- Update to v2.2.0:
  * 2dfcbfd Add support to define CATTLE_AGENT_STRICT_VERIFY (#1616)
* Tue Oct  1 2024 elemental@suse.de
- Update to v2.2.0-rc1:
  * 01444ac Bump elemental-toolkit to latest v2.2.x (#1592)
  * a0c30fc Adding the new arm-firmware feature for aarch64 builds (#1590)
  * a9c1d57 Disable predictable interface names (bsc#1230904) (#1581)
  * 35b34fd Include a baremetal disk image
  * 764b791 Switch to git in OBS (#1562)
  * 415c2ea Install nm-configurator in dev image and simplify dev sample
    manifest (#1533)
  * 31c322a Support for IPAM to nmstate (#1476)
  * dba9c98 Remove unneeded network setup
  * 36207b6 elemental.spec: Add procps to Requires
  * fde4fe2 Add openSSH server to SELinux images
  * 2ef9dd7 Revert "Move install openssh and openssh-server"
  * 462b1b8 Move install openssh and openssh-server
  * a267562 selinux config file no longer needed
  * 0b88900 Configure SELinux for RKE2 image
  * 9fd1cd7 Add relabelling initramfs step
  * 016914b Add explicit enforcing setup
  * bec23e9 Set SELinux in permissive mode on recovery, leave default on
    active
  * 80a9efe Move mount config files to /run/elemental
  * fe8e0fc Removing syslinux from base image
  * 7f668e9 Fix grub2-x86_64-efi installation
  * 8b8c89a Update framework/files/system/oem/01_elemental-rootfs.yaml
  * 7675473 Set layout with yaml format
  * 650493a Drop unused accounting.yaml
  * db7f55a use patterns-microos-selinux instead of individual packages
  * b6720b9 Add flavors for k3s-selinux and rke2-selinux KVM images
  * cc1a6ee Rebase dev image to Tumbleweed (#1363)
  * 994a0c3 Use default compression (gzip) for ISOs
  * 0d67032 No squashfs compression by default
  * 8787081 Get rid of few error messages in OBS builds
  * f2f3e65 Update spec file to new bootargs.cfg location
  * 24dca6e Move bootargs to /etc/elemental
  * 8edb9ba Include boot assessment installation as part of elemental init
  * 7a04678 Do not start elemental-register timer manually
  * 37f60bf Update .obs/dockerfile/micro-rt-iso/Dockerfile
  * 6019373 Update .obs/dockerfile/micro-kvm-iso/Dockerfile
  * f8ef719 Update .obs/dockerfile/micro-base-iso/Dockerfile
  * 60de594 Update .obs/dockerfile/micro-baremetal-iso/Dockerfile
  * 6d90f32 Use the naming convention OBS expects for ISOs
  * c01a9a1 Add an elemental-register checker
  * 54c94ff Adding an network-online checker for elemental
  * c50d518 Fix RT ISO name
  * 1b9cf0f Update workflow to new SL Micro name
  * 98d06fc micro-rt-os/Dockerfile: Tag consistently
  * a479e2b Dockefile: Add #!UseOBSRepositories
  * 8f61703 Add wireless-regdb for aarch64
  * 530dc33 Finalize Micro rename
  * 2b6cf4d Install openssl in micro-base
  * 39b1fad Micro rename
  * e4e1206 Include audit package and boot selinux in permissive mode
    explicitly
  * f358223 Sync kvm and rt ISO sources in OBS
  * f7f9de3 Only apply upgrade config on OS upgrades (#1283)
  * a5afd95 Actualize development documentation (#1271)
  * 005e933 slem-rt-iso: fix ISO name
  * 7b23fee Disable selinux for recovery
  * 77aaac2 rt: move ARG after FROM
  * c1abf48 rt, kvm: fix tags and references
  * 98584eb kvm, rt: Add BuildName
  * 886f710 Use busybox in RT and KVM iso images
  * 6fee308 Include busybox to ISO images from scratch
  * eb74c83 slem-base-os: Drop apparmor-parser
  * 13344e6 Switch from busybox to toolbox for ALP
  * e00d917 Fix labelprefix for ALP
  * b9ebc0a slem-iso: SLE_VERSION -> SLEMICRO_VERSION on ALP
  * 17a5133 slem-iso: move from busybox to toolbox on ALP
  * 5a73e00 Drop builder container in favor of sle-micro/6.0/toolbox
  * 99c7c44 Switch to sle-micro/6.0/toolbox as host
  * 14c46a2 Back to SLE15 busybox
  * 85e97d3 Move to alp/bci/busybox
  * a6267b4 Adapt Dockerfiles for ALP
  * ccd4598 drop %%VERSION%% in IMG_TAG
  * 9c8403f fix VERSION
  * 474b8b1 Unify syntax
  * 351a396 add SLEMICRO_VERSION suffix
  * 08f1118 Build slem-base-os with slem-builder-container
  * 3d27650 drop -base- from builder container
  * 87e8d8b A builder container
  * 34018d3 Back to SLE15 busybox
  * f21de6d Add btrfsmaintance to base container
  * 1b92b57 Move to alp/bci/busybox
  * 382730c slem-kvm-iso/Dockerfile: fix IMG_REPO
  * 65224b7 Add slem-rt-iso Dockerfile and manifest.yaml
  * c5dc64b Add slem-kvm-iso Dockerfile
  * e7f9844 Drop haveged - included in kernel now
  * dd525b0 slem-base-os: explicitly install kernel-default
  * de2fa1f drop k9s and nfsidmap, not available in SLE Micro 6
  * 91eb5ef Adapt Dockerfiles for ALP
* Mon Sep 23 2024 dcassany@suse.com
- Include net.ifnames=0 kernel parameter bsc#1230904
* Mon Aug  5 2024 dcassany@suse.com
- Update to version v2.1.2
  * Fix grub2-x86_64-efi installation
  * Removing syslinux from base image
  * Workaround to remove any pre-existing Elemental initrd
* Fri Apr 26 2024 dcassany@suse.com
- Update to version v2.1.1
  * Move bootargs to /etc/elemental
  * Include boot assessment installation as part of elemental init
  * Do not start elemental-register timer manually
  * Add an elemental-register checker
  * Adding an network-online checker for elemental
  * Add wireless-regdb for aarch64
* Wed Mar 13 2024 dcassany@suse.com
- Bump to v2.1.0
  * Micro rename
  * Only apply upgrade config on OS upgrades (#1283)
  * Require elemental-toolkit v2
  * Adding the btrfs default at elemental-operator level
  * Enable recovery upgrades (#1226)
  * Set transient recovery hostname
  * Update all Golang dependencies
  * Adapt bootargs file to support btrfs snapshotter (#1213)
  * Adapt upgrade script to the new elemental-toolkit
  * Don't set the hostname (#1171)
  * Make use of the update elemental kernel arguments
  * Make initrd generation consistent across flavors
  * Update rootfs settings
  * Make sure no variables in /etc/os-release are duplicated
  * Build RT flavour only for x86_64
  * Use Elemental systemd branding package
  * Update kernel cmdline for elemental-sysroot (#1165)
  * Use the elemental-rootfs feature (#1163)
  * Run services after time-sync.target
  * Mkdir /host/run/elemental in suc-upgrade
  * Migrate to /run/elemental from /run/cos
  * Add default network configuration for eth0
  * Remove default serial console kernel parameter
* Tue Nov 28 2023 dcassany@suse.com
- Update to version 2.0.0:
  * For some reason OBS complains of invalid format on SOURCEURL substitution
  * Update workflow so that it branches the appropriate OBS packages
  * Adding missing manifest for the base-iso image
  * Align and update labels and tags with all images
  * Remove obsolete images, sle micro variants are already in place
  * Rename build-iso-next
  * Remove longhorn overlay mount
  * Drop the 'for Rancher' suffix
  * Revert to 'old' RPi firmware
  * Set entrypoint of elemental-iso-add-registration
  * Fix SLEM4R OS build
  * Update elemental-iso-add-registration
  * Remove some old teal references
  * Remove Teal images
  * Bump ele-testhelpers deps
  * Include system agent unit file in specfile
  * Require elemental-toolkit instead of elemental-cli (#984)
* Tue Nov 28 2023 dcassany@suse.com
- Update to version 1.3+git20230830.d301e1b:
  * Add elemental-register-reset.service
  * Use the new init command (#874)
  * Disable service triggers on staging
  * Fix elemental-iso-add-registration script
  * rancher/ -> suse/
  * Use elemental-register --install argument (#934)
  * Allow installation on non-SUSE distributions
  * Add CONTRIBUTING.md
  * Enable cloud-config from removable devices
  * Ensure names are unique for all stages
  * Do not compare versions from different repositories on upgrades
  * Feat: add CODEOWNERS
  * Load proxy setup from sysconfig and allow elemental specific env variables
  * Include cryptsetup in elemental-teal
  * Do not expand COS_PERSISTENT by default
  * Add environment variable files in elemental-system-agent.service
  * Run elemental-register in systemd service (#723)
  * Include rke2-killall on shutdown process
  * Update shutdown-k3s.service
  * Prevent upgrade loops when FORCE is in use
  * Do not allow downgrades without force flag
  * Remove reboots on cloud-config addition
  * Do not allow concurrent suc-upgrade executions
  * Update docker/login-action to v2.1.0 (#666)
  * Add shutdown-k3s.service to OBS spec
  * Add service to kill k3s before umount
* Tue Nov 28 2023 dcassany@suse.com
- Update to version 1.1.0+git20230125.14a106c:
  * Add debug flag on upgrade command and update bootargs.cfg file (#625)
* Tue Oct 25 2022 kkaempf@suse.com
- add /etc/NetworkManager/conf.d/rke2-canal.conf (#446)
* Wed Oct  5 2022 dcassany@suse.com
- Initial commit
